==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/nb-NO/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => '<strong>CronJob</strong> Status',
    '<strong>Queue</strong> Status' => '<strong>Kø</strong> Status',
    'About HumHub' => 'Om Humhub',
    'Background Jobs' => 'Bakgrunnsjobber',
    'Base URL' => 'Nettsidens adresse',
    'Checking HumHub software prerequisites.' => 'Kontrollerer HumHub software krav',
    'Database' => 'Database',
    'Database migration results:' => 'Database migreringeresultater:',
    'Delayed' => 'Forsinket',
    'Displaying {count} entries per page.' => 'Vis {count} oppføringer pr side.',
    'Done' => 'Utført',
    'Driver' => 'Driver',
    'Error' => 'Feil',
    'Flush entries' => 'Tøm oppføringer',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub er for tiden i feilsøkingsmodus. Deaktiver den når du kjører på produksjon.',
    'Last run (daily):' => 'Siste kjøring (daglig):',
    'Last run (hourly):' => 'Siste kjøring (per time):',
    'Licences' => 'Lisens',
    'Logging' => 'Logger',
    'Never' => 'Aldri',
    'Other' => 'Andre',
    'Permissions' => 'Tilatelser',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Vennligst se dokumentasjonen for å sette opp cronjobs og køarbeidere.',
    'Prerequisites' => 'Forutsetninger',
    'Queue successfully cleared.' => 'Køen er tømt',
    'Re-Run tests' => 'Test på nytt',
    'Reserved' => 'Tilbakestilt',
    'Search index rebuild in progress.' => 'Søke indeksen bygges på nytt',
    'See installation manual for more details.' => 'Se installasjonsmanualen for flere detaljer.',
    'Settings' => 'Innstillinger',
    'The current main HumHub database name is ' => 'Den nåværende hoved HumHub databasenavn er',
    'There is a new update available! (Latest version: %version%)' => 'Det er en ny oppdatering tilgjengelig. (Siste versjon: %version%)',
    'This HumHub installation is up to date!' => 'Denne HumHub installasjonen kjører på siste versjon.',
    'Total {count} entries found.' => 'Totalt {count} oppføringer funnet.',
    'Waiting' => 'Venter',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Dynamic Config' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Search term...' => '',
    'Select category..' => '',
    'Select day' => '',
    'Select level...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Warning' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/nb-NO/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => '<strong>CronJob</strong> Status',
    '<strong>Queue</strong> Status' => '<strong>Kø</strong> Status',
    'About HumHub' => 'Om Humhub',
    'Background Jobs' => 'Bakgrunnsjobber',
    'Base URL' => 'Nettsidens adresse',
    'Checking HumHub software prerequisites.' => 'Kontrollerer HumHub software krav',
    'Database' => 'Database',
    'Database migration results:' => 'Database migreringeresultater:',
    'Delayed' => 'Forsinket',
    'Displaying {count} entries per page.' => 'Vis {count} oppføringer pr side.',
    'Done' => 'Utført',
    'Driver' => 'Driver',
    'Error' => 'Feil',
    'Flush entries' => 'Tøm oppføringer',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub er for tiden i feilsøkingsmodus. Deaktiver den når du kjører på produksjon.',
    'Last run (daily):' => 'Siste kjøring (daglig):',
    'Last run (hourly):' => 'Siste kjøring (per time):',
    'Licences' => 'Lisens',
    'Logging' => 'Logger',
    'Never' => 'Aldri',
    'Other' => 'Andre',
    'Permissions' => 'Tilatelser',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Vennligst se dokumentasjonen for å sette opp cronjobs og køarbeidere.',
    'Prerequisites' => 'Forutsetninger',
    'Queue successfully cleared.' => 'Køen er tømt',
    'Re-Run tests' => 'Test på nytt',
    'Reserved' => 'Tilbakestilt',
    'Search index rebuild in progress.' => 'Søke indeksen bygges på nytt',
    'See installation manual for more details.' => 'Se installasjonsmanualen for flere detaljer.',
    'Settings' => 'Innstillinger',
    'The current main HumHub database name is ' => 'Den nåværende hoved HumHub databasenavn er',
    'There is a new update available! (Latest version: %version%)' => 'Det er en ny oppdatering tilgjengelig. (Siste versjon: %version%)',
    'This HumHub installation is up to date!' => 'Denne HumHub installasjonen kjører på siste versjon.',
    'Total {count} entries found.' => 'Totalt {count} oppføringer funnet.',
    'Waiting' => 'Venter',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Enable <a href="{url}">Link Redirection Service</a>' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for Mercure push live driver' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Search term...' => '',
    'Select category..' => '',
    'Select day' => '',
    'Select level...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Uploads - File' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Warning' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];
